@@ -1,5 +1,8 @@
+import re
+
 from django import forms
-from django.core.exceptions import MultipleObjectsReturned, ObjectDoesNotExist
+from django.conf import settings
+from django.core.exceptions import MultipleObjectsReturned, ObjectDoesNotExist, ValidationError
 from django.utils.translation import gettext as _
 
 from extras.models import Tag
@@ -9,11 +12,11 @@ from ipam.models import IPAddress
 from ipam.formfields import IPNetworkFormField
 from utilities.forms import (
     BootstrapMixin, DynamicModelChoiceField, BulkEditForm,
-    DynamicModelMultipleChoiceField, StaticSelect2,
-    APISelect, APISelectMultiple, StaticSelect2Multiple, TagFilterField
+    DynamicModelMultipleChoiceField, StaticSelect,
+    APISelect, APISelectMultiple, StaticSelectMultiple, TagFilterField
 )
 from extras.forms import (
-    CustomFieldModelForm, CustomFieldBulkEditForm, CustomFieldFilterForm
+    CustomFieldModelForm, CustomFieldBulkEditForm
 )
 
 from .models import (
@@ -22,6 +25,49 @@ from .models import (
 )
 
 
+from django.forms.widgets import TextInput
+
+
+class ASNField(forms.CharField):
+    '''
+    Return int value, but allows to input dotted digit text
+    '''
+
+    def to_python(self, value):
+        if not re.match(r'^\d+(\.\d+)?$', value):
+            raise ValidationError('Invalid AS Number: {}'.format(value))       
+        if '.' in value:
+            if int(value.split('.')[0]) > 65535 or int(value.split('.')[1]) > 65535:
+                raise ValidationError('Invalid AS Number: {}'.format(value))
+            try:
+                return int(value.split('.')[0]) * 65536 + int(value.split('.')[1])
+            except ValueError:
+                raise ValidationError('Invalid AS Number: {}'.format(value))
+        try:
+            return int(value)
+        except ValueError:
+            raise ValidationError('Invalid AS Number: {}'.format(value))
+
+
+class ASdotInput(TextInput):
+    def _format_value(self, value):
+        if not value:
+            return 0
+        if type(value) is str:
+            return value
+        if int(value) > 65535:
+            return '{}.{}'.format(value // 65536, value % 65536)
+        else:
+            return value
+
+    def render(self, name, value, attrs=None, renderer=None):
+        nb_settings = settings.PLUGINS_CONFIG.get('netbox_bgp', {})
+        asdot = nb_settings.get('asdot', False)
+        if asdot:
+            value = self._format_value(value)
+        return super().render(name, value, attrs, renderer)
+
+
 class ASNFilterForm(BootstrapMixin, CustomFieldModelForm):
     q = forms.CharField(
         required=False,
@@ -34,7 +80,7 @@ class ASNFilterForm(BootstrapMixin, CustomFieldModelForm):
     status = forms.MultipleChoiceField(
         choices=ASNStatusChoices,
         required=False,
-        widget=StaticSelect2Multiple()
+        widget=StaticSelectMultiple()
     )
     site = DynamicModelChoiceField(
         queryset=Site.objects.all(),
@@ -49,6 +95,9 @@ class ASNFilterForm(BootstrapMixin, CustomFieldModelForm):
 
 
 class ASNForm(BootstrapMixin, CustomFieldModelForm):
+    number = ASNField(
+        widget=ASdotInput
+    )
     tags = DynamicModelMultipleChoiceField(
         queryset=Tag.objects.all(),
         required=False
@@ -63,13 +112,15 @@ class ASNForm(BootstrapMixin, CustomFieldModelForm):
     )
 
     def clean(self):
-        cleaned_data = self.cleaned_data
-        number = cleaned_data['number']
+        cleaned_data = super().clean()
+        if self.errors.get('number'):
+            return cleaned_data
+        number = cleaned_data.get('number')
         tenant = cleaned_data.get('tenant')
         if 'number' in self.changed_data or 'tenant' in self.changed_data:
             if ASN.objects.filter(number=number, tenant=tenant).exists():
                 raise forms.ValidationError('AS number with this number and tenant is already exists.')
-        return super().clean()
+        return cleaned_data
 
     class Meta:
         model = ASN
@@ -78,7 +129,7 @@ class ASNForm(BootstrapMixin, CustomFieldModelForm):
         ]
 
 
-class ASNBulkEditForm(BootstrapMixin, CustomFieldBulkEditForm):
+class ASNBulkEditForm(CustomFieldBulkEditForm):
     pk = forms.ModelMultipleChoiceField(
         queryset=ASN.objects.all(),
         widget=forms.MultipleHiddenInput
@@ -94,7 +145,7 @@ class ASNBulkEditForm(BootstrapMixin, CustomFieldBulkEditForm):
     status = forms.ChoiceField(
         required=False,
         choices=ASNStatusChoices,
-        widget=StaticSelect2()
+        widget=StaticSelect()
     )
 
     class Meta:
@@ -132,7 +183,7 @@ class CommunityFilterForm(BootstrapMixin, forms.ModelForm):
     status = forms.MultipleChoiceField(
         choices=ASNStatusChoices,
         required=False,
-        widget=StaticSelect2Multiple()
+        widget=StaticSelectMultiple()
     )
     site = DynamicModelChoiceField(
         queryset=Site.objects.all(),
@@ -162,7 +213,7 @@ class CommunityBulkEditForm(BootstrapMixin, BulkEditForm):
     status = forms.ChoiceField(
         required=False,
         choices=ASNStatusChoices,
-        widget=StaticSelect2()
+        widget=StaticSelect()
     )
 
     class Meta:
@@ -200,7 +251,6 @@ class BGPSessionForm(BootstrapMixin, CustomFieldModelForm):
         query_params={
             'site_id': '$site'
         },
-        display_field='number',
         widget=APISelect(
             api_url='/api/plugins/bgp/asn/',
         )
@@ -211,18 +261,19 @@ class BGPSessionForm(BootstrapMixin, CustomFieldModelForm):
         query_params={
             'site_id': '$site'
         },
-        display_field='number',
         widget=APISelect(
             api_url='/api/plugins/bgp/asn/',
         )
     )
     local_address = DynamicModelChoiceField(
         queryset=IPAddress.objects.all(),
-        display_field='address',
         query_params={
             'device_id': '$device'
         }
     )
+    remote_address = DynamicModelChoiceField(
+        queryset=IPAddress.objects.all(),
+    )
     peer_group = DynamicModelChoiceField(
         queryset=BGPPeerGroup.objects.all(),
         required=False,
@@ -258,6 +309,9 @@ class BGPSessionForm(BootstrapMixin, CustomFieldModelForm):
             ('Local', ('local_as', 'local_address')),
             ('Policies', ('import_policies', 'export_policies'))
         )
+        widgets = {
+            'status': StaticSelect(),
+        }
 
 
 class BGPSessionAddForm(BGPSessionForm):
@@ -279,18 +333,18 @@ class BGPSessionFilterForm(BootstrapMixin, CustomFieldModelForm):
         required=False,
         label='Search'
     )
-    remote_as = DynamicModelMultipleChoiceField(
+    remote_as_id = DynamicModelMultipleChoiceField(
         queryset=ASN.objects.all(),
         required=False,
-        display_field='number',
+        label=_('Remote AS'),
         widget=APISelectMultiple(
             api_url='/api/plugins/bgp/asn/',
         )
     )
-    local_as = DynamicModelMultipleChoiceField(
+    local_as_id = DynamicModelMultipleChoiceField(
         queryset=ASN.objects.all(),
         required=False,
-        display_field='number',
+        label=_('Local AS'),
         widget=APISelectMultiple(
             api_url='/api/plugins/bgp/asn/',
         )
@@ -311,7 +365,7 @@ class BGPSessionFilterForm(BootstrapMixin, CustomFieldModelForm):
     status = forms.MultipleChoiceField(
         choices=SessionStatusChoices,
         required=False,
-        widget=StaticSelect2Multiple()
+        widget=StaticSelectMultiple()
     )
     peer_group = DynamicModelMultipleChoiceField(
         queryset=BGPPeerGroup.objects.all(),
@@ -343,7 +397,7 @@ class BGPSessionFilterForm(BootstrapMixin, CustomFieldModelForm):
 
     class Meta:
         model = BGPSession
-        fields = ['q', 'status', 'device_id', 'remote_as', 'local_as']
+        fields = ['q', 'status', 'device_id']
 
 
 class RoutingPolicyFilterForm(BootstrapMixin, CustomFieldModelForm):
